# Version file autogenerated by the build process
version = '0.12.2'
build = 1242
vcs_info = 'Git SHA1 a78f1079 committed on 2023-10-05'
package_name = 'ksconf'

if __name__ == '__main__':
    print('KSCONF_VERSION="0.12.2"\nKSCONF_BUILD="1242"\nKSCONF_VCS_INFO="Git SHA1 a78f1079 committed on 2023-10-05"')
